@@ -18,9 +18,7 @@
  ***************************************************************************/
 
 #include "gwconnector.h"
-#include <k3bufferedsocket.h>
 #include <kdebug.h>
-#include <k3resolver.h>
 
 #include "gwerror.h"
 #include "gwbytestream.h"
@@ -65,7 +63,7 @@ void KNetworkConnector::connectToServer ( const QString & /*server*/ )
 
 void KNetworkConnector::slotConnected ()
 {
-	kDebug() << "We are connected.";
+	qDebug() << "We are connected.";
 
 	// FIXME: setPeerAddress() is something different, find out correct usage later
 	//KInetSocketAddress inetAddress = mStreamSocket->address().asInet().makeIPv6 ();
@@ -77,7 +75,7 @@ void KNetworkConnector::slotConnected ()
 
 void KNetworkConnector::slotError ( int code )
 {
-	kDebug() << "Error detected: " << code;
+	qDebug() << "Error detected: " << code;
 
 	mErrorCode = code;
 	emit error ();
@@ -120,4 +118,3 @@ void KNetworkConnector::setOptSSL ( bool ssl )
 
 }
 
-#include "gwconnector.moc"
